Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Size is max width or height of the thumbnail image Size uint = 256 // Quality is the thumbnail jpeg quality Quality int = 90 )
var Font, _ = freetype.ParseFont(fontBytes)
Font - Bitstream Vera
Functions ¶
This section is empty.
Types ¶
type Thumbnail ¶
type Thumbnail struct {
Data []byte `json:"data"`
MIME string `json:"mime"`
Bounds image.Rectangle `json:"bounds"`
}
Thumbnail contains a thumbnail image in bytes + the MIME type and bounds
func GetFromURL ¶
GetFromURL downloads the image at the given URL and returns the thumbnail
Click to show internal directories.
Click to hide internal directories.